@@ -274,7 +274,8 @@ def invalid_command_message(mod, exit_on_error):
         return False
 
 
-def parse_and_run_command(argv, mod, default_command=None, exit_on_error=True):
+def parse_and_run_command(argv, mod, default_command=None, exit_on_error=True,
+                          extra_options=None):
     """
     A one-shot function that parses the args, and then runs the command
     that the user specifies.  If you set a default_command, and they don't
@@ -288,6 +289,9 @@ def parse_and_run_command(argv, mod, default_command=None, exit_on_error=True):
     try:
         command, options = parse(argv)
 
+        if extra_options:
+            options.update(extra_options)
+
         if not command and default_command:
             command = default_command
         elif not command and not default_command:
@@ -304,3 +308,17 @@ def parse_and_run_command(argv, mod, default_command=None, exit_on_error=True):
 
     return True
 
+
+def load_module(name):
+    try:
+        mod = __import__(name)
+    except ImportError:
+        return None
+
+    components = name.split('.')
+
+    for comp in components[1:]:
+        mod = getattr(mod, comp)
+
+    return mod
+
